@@ -2,12 +2,12 @@ mod property;
 
 pub use property::*;
 
-use std::{fmt::Display, ops::Deref};
+use std::{fmt::Display, ops::{Deref, DerefMut}};
 
 /// A set of [`Property`]s.
 #[derive(Debug, Default, Clone, Eq, PartialEq, Ord, PartialOrd)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
-pub struct Properties(Vec<Property>);
+pub struct Properties(pub Vec<Property>);
 
 impl Properties {
     pub fn new(properties: Vec<Property>) -> Self {
@@ -29,6 +29,12 @@ impl Deref for Properties {
     }
 }
 
+impl DerefMut for Properties {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+
 impl Display for Properties {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         for i in 0..self.len().checked_sub(1).unwrap_or_default() {
