@@ -2,12 +2,12 @@ mod entity;
 
 pub use entity::*;
 
-use std::{fmt::Display, ops::Deref};
+use std::{fmt::Display, ops::{Deref, DerefMut}};
 
 /// A Quake [`map`](https://www.gamers.org/dEngine/quake/QDP/qmapspec.html) containing one or more [`Entity`]s.
 #[derive(Debug, Default, Clone, PartialEq, PartialOrd)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
-pub struct Map(Vec<Entity>);
+pub struct Map(pub Vec<Entity>);
 
 impl Map {
     pub fn new(entities: Vec<Entity>) -> Self {
@@ -29,6 +29,12 @@ impl Deref for Map {
     }
 }
 
+impl DerefMut for Map {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+
 impl Display for Map {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         for i in 0..self.len().checked_sub(1).unwrap_or_default() {
